Package: shinyToastify
Type: Package
Title: Pretty Notifications for 'Shiny'
Version: 2.0.0
Authors@R: c(
    person(given = "Stéphane",
           family = "Laurent",
           role = c("aut", "cre"),
           email = "laurent_step@outlook.fr"),
    person(given = "Fadi",
           family = "Khadra",
           role = "cph",
           comment = "'React-Toastify' library (https://fkhadra.github.io/react-toastify/introduction)"))
Description: This is a wrapper of the 'React' library 'React-Toastify'. It allows to show some notifications (toasts) in 'Shiny' applications. There are options for the style, the position, the transition effect, and more.
License: GPL-3
Encoding: UTF-8
URL: https://github.com/stla/shinyToastify
BugReports: https://github.com/stla/shinyToastify/issues
Imports: htmltools, reactR, shiny, utils, fontawesome
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-07-31 10:44:29 UTC; SDL96354
Author: Stéphane Laurent [aut, cre],
  Fadi Khadra [cph] ('React-Toastify' library
    (https://fkhadra.github.io/react-toastify/introduction))
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2021-07-31 11:00:01 UTC
Built: R 4.6.0; ; 2026-04-28 21:19:51 UTC; unix
