# Generated by roxygen2: do not edit by hand

export(shinyToastifyExample)
export(shinyToastifyExamples)
export(showToast)
export(toastUpdate)
export(useShinyToastify)
importFrom(fontawesome,fa_html_dependency)
importFrom(htmltools,HTML)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tags)
importFrom(reactR,createReactShinyInput)
importFrom(shiny,observeEvent)
importFrom(shiny,runApp)
importFrom(utils,URLencode)
