# shinyToastify

This is a wrapper of the 'React' library 'React-Toastify' for usage in Shiny 
applications. 

### Six available types:

![](https://raw.githubusercontent.com/stla/shinyToastify/main/inst/screenshots/toastTypes.gif)

The toast container and the toast body are easily customizable.

### Four available transitions:

![](https://raw.githubusercontent.com/stla/shinyToastify/main/inst/screenshots/toastTransitions.gif)

### Toast are better with **fontawesome** icons:

![](https://raw.githubusercontent.com/stla/shinyToastify/main/inst/screenshots/toastIcons.gif)

### Callbacks

It is possible to execute a R callback and/or a JavaScript callback whenever 
a toast closes. 
